// Layer Shader Enum header
//
// This file is auto-generated by cmake, don't edit it.

absval = 0,
batchnorm = 1,
batchnorm_pack4 = 2,
concat = 3,
concat_pack4 = 4,
concat_pack4to1 = 5,
convolution_1x1s1d1_cm = 6,
convolution_3x3s1d1_winograd23_transform_input = 7,
convolution_3x3s1d1_winograd23_transform_output = 8,
convolution_3x3s1d1_winograd43_transform_input = 9,
convolution_3x3s1d1_winograd43_transform_output = 10,
convolution_3x3s1d1_winograd_gemm = 11,
convolution_gemm_cm = 12,
convolution_pack1to4_3x3s1d1_winograd_gemm = 13,
convolution_pack4_3x3s1d1_winograd23_transform_input = 14,
convolution_pack4_3x3s1d1_winograd23_transform_output = 15,
convolution_pack4_3x3s1d1_winograd43_transform_input = 16,
convolution_pack4_3x3s1d1_winograd43_transform_output = 17,
convolution_pack4_3x3s1d1_winograd_gemm = 18,
convolution_pack4to1_3x3s1d1_winograd_gemm = 19,
convolution_packed = 20,
convolution_packed_1x1s1d1 = 21,
convolution_packed_gemm = 22,
convolution_winograd_gemm_cm = 23,
crop = 24,
crop_pack1to4 = 25,
crop_pack4 = 26,
crop_pack4to1 = 27,
deconvolution_col2im = 28,
deconvolution_gemm_cm = 29,
deconvolution_gemm_packed = 30,
deconvolution_pack4_col2im = 31,
deconvolution_packed = 32,
dropout = 33,
eltwise = 34,
elu = 35,
flatten = 36,
flatten_pack1to4 = 37,
flatten_pack4 = 38,
innerproduct = 39,
innerproduct_gemm = 40,
innerproduct_gemm_wp1to4 = 41,
innerproduct_gemm_wp4 = 42,
innerproduct_gemm_wp4to1 = 43,
innerproduct_pack1to4 = 44,
innerproduct_pack4 = 45,
innerproduct_pack4to1 = 46,
innerproduct_reduce_sum8 = 47,
innerproduct_reduce_sum8_pack4 = 48,
innerproduct_sum8 = 49,
innerproduct_sum8_pack1to4 = 50,
innerproduct_sum8_pack4 = 51,
innerproduct_sum8_pack4to1 = 52,
lrn_norm = 53,
lrn_norm_across_channel_pack4 = 54,
lrn_norm_within_channel_pack4 = 55,
lrn_square_pad = 56,
lrn_square_pad_across_channel_pack4 = 57,
lrn_square_pad_within_channel_pack4 = 58,
pooling = 59,
pooling_adaptive = 60,
pooling_adaptive_pack4 = 61,
pooling_global_reduce_max = 62,
pooling_global_reduce_max_first = 63,
pooling_global_reduce_max_first_pack4 = 64,
pooling_global_reduce_max_last = 65,
pooling_global_reduce_max_last_pack4 = 66,
pooling_global_reduce_max_pack4 = 67,
pooling_global_reduce_sum = 68,
pooling_global_reduce_sum_first = 69,
pooling_global_reduce_sum_first_pack4 = 70,
pooling_global_reduce_sum_last = 71,
pooling_global_reduce_sum_last_pack4 = 72,
pooling_global_reduce_sum_pack4 = 73,
pooling_pack4 = 74,
prelu = 75,
prelu_pack4 = 76,
reduction = 77,
relu = 78,
reshape = 79,
reshape_pack1to4 = 80,
reshape_pack4 = 81,
reshape_pack4to1 = 82,
scale = 83,
scale_pack4 = 84,
sigmoid = 85,
slice = 86,
slice_pack1to4 = 87,
slice_pack4 = 88,
softmax_div_sum = 89,
softmax_div_sum_pack4 = 90,
softmax_exp_sub_max = 91,
softmax_exp_sub_max_pack4 = 92,
softmax_reduce_max = 93,
softmax_reduce_max_pack4 = 94,
softmax_reduce_sum = 95,
softmax_reduce_sum_pack4 = 96,
tanh = 97,
binaryop = 98,
binaryop_broadcast = 99,
binaryop_broadcast_pack1to4 = 100,
binaryop_broadcast_pack4 = 101,
binaryop_pack4 = 102,
unaryop = 103,
convolutiondepthwise = 104,
convolutiondepthwise_group = 105,
convolutiondepthwise_group_pack1to4 = 106,
convolutiondepthwise_group_pack4 = 107,
convolutiondepthwise_group_pack4to1 = 108,
convolutiondepthwise_pack4 = 109,
padding = 110,
padding_3d = 111,
padding_3d_pack4 = 112,
padding_pack1to4 = 113,
padding_pack4 = 114,
padding_pack4to1 = 115,
normalize_coeffs = 116,
normalize_coeffs_pack4 = 117,
normalize_norm = 118,
normalize_norm_pack4 = 119,
normalize_reduce_sum4_fp16_to_fp32 = 120,
normalize_reduce_sum4_fp16_to_fp32_pack4 = 121,
normalize_reduce_sum4_fp32 = 122,
normalize_reduce_sum4_fp32_pack4 = 123,
permute = 124,
permute_pack1to4 = 125,
permute_pack4 = 126,
permute_pack4to1 = 127,
priorbox = 128,
priorbox_mxnet = 129,
interp = 130,
interp_bicubic = 131,
interp_bicubic_coeffs = 132,
interp_bicubic_pack4 = 133,
interp_pack4 = 134,
deconvolutiondepthwise = 135,
deconvolutiondepthwise_group = 136,
deconvolutiondepthwise_group_pack1to4 = 137,
deconvolutiondepthwise_group_pack4 = 138,
deconvolutiondepthwise_group_pack4to1 = 139,
deconvolutiondepthwise_pack4 = 140,
shufflechannel = 141,
shufflechannel_pack4 = 142,
instancenorm_coeffs = 143,
instancenorm_coeffs_pack4 = 144,
instancenorm_norm = 145,
instancenorm_norm_pack4 = 146,
instancenorm_reduce_mean = 147,
instancenorm_reduce_mean_pack4 = 148,
instancenorm_reduce_sum4_fp16_to_fp32 = 149,
instancenorm_reduce_sum4_fp16_to_fp32_pack4 = 150,
instancenorm_reduce_sum4_fp32 = 151,
instancenorm_reduce_sum4_fp32_pack4 = 152,
instancenorm_sub_mean_square = 153,
instancenorm_sub_mean_square_pack4 = 154,
clip = 155,
reorg = 156,
reorg_pack1to4 = 157,
reorg_pack4 = 158,
quantize = 159,
quantize_pack4 = 160,
dequantize = 161,
dequantize_pack4 = 162,
packing = 163,
packing_int8 = 164,
packing_pack1to4 = 165,
packing_pack1to4_int8 = 166,
packing_pack4to1 = 167,
packing_pack4to1_int8 = 168,
requantize = 169,
requantize_pack4 = 170,
cast_fp16_to_fp32 = 171,
cast_fp16_to_fp32_pack4 = 172,
cast_fp32_to_fp16 = 173,
cast_fp32_to_fp16_pack4 = 174,
hardsigmoid = 175,
selu = 176,
hardswish = 177,
pixelshuffle = 178,
pixelshuffle_pack4 = 179,
pixelshuffle_pack4to1 = 180,
deepcopy = 181,
deepcopy_pack4 = 182,
mish = 183,
swish = 184,
gemm = 185,
gemm_cm = 186,
gemm_sg = 187,
groupnorm_coeffs = 188,
groupnorm_coeffs_pack4 = 189,
groupnorm_norm = 190,
groupnorm_norm_pack4 = 191,
groupnorm_reduce_mean = 192,
groupnorm_reduce_mean_pack4 = 193,
groupnorm_reduce_sum4_fp16_to_fp32 = 194,
groupnorm_reduce_sum4_fp16_to_fp32_pack4 = 195,
groupnorm_reduce_sum4_fp32 = 196,
groupnorm_reduce_sum4_fp32_pack4 = 197,
groupnorm_sub_mean_square = 198,
groupnorm_sub_mean_square_pack4 = 199,
layernorm_coeffs = 200,
layernorm_coeffs_pack4 = 201,
layernorm_norm = 202,
layernorm_norm_pack4 = 203,
layernorm_reduce_mean = 204,
layernorm_reduce_mean_pack4 = 205,
layernorm_reduce_sum4_fp16_to_fp32 = 206,
layernorm_reduce_sum4_fp16_to_fp32_pack4 = 207,
layernorm_reduce_sum4_fp32 = 208,
layernorm_reduce_sum4_fp32_pack4 = 209,
layernorm_sub_mean_square = 210,
layernorm_sub_mean_square_pack4 = 211,
softplus = 212,
multiheadattention_qk_cross = 213,
multiheadattention_qk_cross_pack1to4 = 214,
multiheadattention_qk_cross_pack4 = 215,
multiheadattention_qk_cross_pack4to1 = 216,
multiheadattention_qkv_cross = 217,
multiheadattention_qkv_cross_pack1to4 = 218,
multiheadattention_qkv_cross_pack4 = 219,
multiheadattention_qkv_cross_pack4to1 = 220,
gelu = 221,
convolution1d_1x1s1d1_cm = 222,
convolution1d_gemm_cm = 223,
convolution1d_packed = 224,
convolution1d_packed_1x1s1d1 = 225,
convolution1d_packed_gemm = 226,
unfold_im2col = 227,
unfold_im2col_pack1to4 = 228,
unfold_im2col_pack4 = 229,
unfold_im2col_pack4to1 = 230,
erf = 231,
celu = 232,
shrink = 233,
rmsnorm_coeffs = 234,
rmsnorm_coeffs_pack4 = 235,
rmsnorm_norm = 236,
rmsnorm_norm_pack4 = 237,
rmsnorm_square = 238,
rmsnorm_square_pack4 = 239,
sdpa_cross = 240,
sdpa_cross_cm = 241,
sdpa_fa = 242,
sdpa_fa_cm = 243,
rotaryembed = 244,
rotaryembed_pack4 = 245,
convert_ycbcr = 246,
vulkan_activation = 247,

